# PeakPo

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.810401.svg)](https://doi.org/10.5281/zenodo.810401)

PeakPo is a Python application for X-ray diffraction analysis of samples at high pressure and high temperature.

Major features include:

- Pressure and temperature estimation
- Phase identification
- Two-dimensional data analysis
- Visual equation-of-state fitting
- Peak fitting
- Visual unit-cell fitting
- Generation of Excel files containing all calculation results

## How to install (under development, may be unstable)

Open a terminal and create a new conda environment:

```
conda create -n peakpo python=3.11 -y
```

Activate the environment:

```
conda activate peakpo
```

Install `PeakPo`:

```
pip install peakpo
```

## How to upgrade

Make sure to change environment:

```
conda activate peakpo
```

```
python -m pip install --upgrade peakpo
```

## How to reinstall

Make sure to change environment:

```
conda activate peakpo
```


```
python -m pip install --force-reinstall peakpo
```

## How to install before 7.9.x

[Installation wiki page](https://github.com/SHDShim/PeakPo/wiki/Installation-and-Update) 

[Installation Google Slides](https://docs.google.com/presentation/d/11nTraMvenpO7E3Cg7NAH2Qa4UpTwjJVcexdU-CPNE9Q/edit?usp=sharing) 


## Where to download executables

I no longer provide executable files. You can still download previous versions from [this Google Drive folder](https://drive.google.com/drive/folders/0B0kkQLbYpQDYfjBGT21uMkx5cU1JMHJIUUhGR1FkdDVUdzFYVUdKR0Zya2NRcFYtUmRVUGM?resourcekey=0-FT-Lc6ZeuUBMaqHzzjZSbg&usp=sharing).

## Where to get help

See [the PeakPo wiki](https://github.com/SHDShim/peakpo/wiki) for detailed instructions on installation, setup, operation, and updates.

## How to cite

S.-H. Shim (2017). PeakPo: A Python software package for X-ray diffraction analysis at high pressure and high temperature. Zenodo. https://doi.org/10.5281/zenodo.810199
